(* Content-type: application/vnd.wolfram.cdf.text *)

(*** Wolfram CDF File ***)
(* http://www.wolfram.com/cdf *)

(* CreatedBy='Mathematica 11.0' *)

(*************************************************************************)
(*                                                                       *)
(*  The Mathematica License under which this file was created prohibits  *)
(*  restricting third parties in receipt of this file from republishing  *)
(*  or redistributing it by any means, including but not limited to      *)
(*  rights management or terms of use, without the express consent of    *)
(*  Wolfram Research, Inc. For additional information concerning CDF     *)
(*  licensing and redistribution see:                                    *)
(*                                                                       *)
(*        www.wolfram.com/cdf/adopting-cdf/licensing-options.html        *)
(*                                                                       *)
(*************************************************************************)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[      1064,         20]
NotebookDataLength[     23566,        536]
NotebookOptionsPosition[     23911,        526]
NotebookOutlinePosition[     24346,        545]
CellTagsIndexPosition[     24303,        542]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{
Cell[TextData[{
 StyleBox["Torsion\n", "Title",
  FontColor->RGBColor[1, 0, 0]],
 StyleBox["\tQingchang Liu, Baoxing Xu and Marek-Jerzy Pindera\nUniversity of \
Virginia, 2018-03-20",
  FontSize->16,
  FontColor->GrayLevel[0]]
}], "Text",
 TextAlignment->Center,
 ExpressionUUID -> "d890e306-93c5-4bdb-a099-038368ecbb65"],

Cell[TextData[{
 "Consider a shaft to be rigidly attached at one end and twisted at the other \
end by a torque ",
 StyleBox["T",
  FontWeight->"Bold",
  FontSlant->"Italic"],
 ", which is applied perpendicular to the axis of the shaft. Such a shaft is \
said to be in torsion.  \nFor a solid shaft subject to a torque ",
 StyleBox["T",
  FontWeight->"Bold",
  FontSlant->"Italic"],
 ", the torsional shearing stress ",
 StyleBox["\[Tau]",
  FontWeight->"Bold",
  FontSlant->"Italic"],
 " at a distance ",
 StyleBox["\[Rho]",
  FontWeight->"Bold",
  FontSlant->"Italic"],
 " from the center of the shaft is"
}], "Text",
 ExpressionUUID -> "117980bf-5498-4d14-8702-14a0b27fe172"],

Cell[TextData[{
 Cell[BoxData[
  FormBox[
   StyleBox[
    RowBox[{"\[Tau]", 
     StyleBox["=",
      FontSlant->"Italic"], 
     StyleBox[
      FractionBox["T\[Rho]", "J"],
      FontSlant->"Italic"]}],
    FontWeight->"Bold"], TraditionalForm]],
  ExpressionUUID -> "29199b12-831d-4c33-886d-7246125220ab"],
 " and ",
 Cell[BoxData[
  FormBox[
   StyleBox[
    RowBox[{
     SubscriptBox["\[Tau]", "max"], "=", 
     FractionBox["Tr", "J"]}],
    FontWeight->"Bold",
    FontSlant->"Italic"], TraditionalForm]],
  ExpressionUUID -> "2b638967-9aa8-4523-ad7c-ca5b27fb48bc"]
}], "Text",
 TextAlignment->Center],

Cell[TextData[{
 "where J is the polar moment of inertia of the section and r is the outer \
radius. \nThe angle \[Phi] through which the shaft length ",
 StyleBox["L",
  FontWeight->"Bold",
  FontSlant->"Italic"],
 " will twist is "
}], "Text",
 ExpressionUUID -> "117980bf-5498-4d14-8702-14a0b27fe172"],

Cell[TextData[{
 StyleBox["\[Phi]=",
  FontWeight->"Bold",
  FontSlant->"Italic"],
 Cell[BoxData[
  FormBox[
   FractionBox["TL", "JG"], TraditionalForm]],
  FontWeight->"Bold",
  FontSlant->"Italic",
  ExpressionUUID -> "3c9fbd5a-b1c4-4ae6-b5c1-64d0c72e8666"]
}], "Text",
 TextAlignment->Center],

Cell[TextData[{
 "where ",
 StyleBox["G",
  FontWeight->"Bold",
  FontSlant->"Italic"],
 " is the shear modulus of the shaft."
}], "Text",
 ExpressionUUID -> "117980bf-5498-4d14-8702-14a0b27fe172"],

Cell[BoxData[
 TagBox[
  StyleBox[
   DynamicModuleBox[{$CellContext`G$$ = 4, $CellContext`L$$ = 
    0.75, $CellContext`pv$$ = 0, $CellContext`R$$ = 
    0.1, $CellContext`reset$$ = False, $CellContext`T$$ = 0, Typeset`show$$ = 
    True, Typeset`bookmarkList$$ = {}, Typeset`bookmarkMode$$ = "Menu", 
    Typeset`animator$$, Typeset`animvar$$ = 1, Typeset`name$$ = 
    "\"\:65e0\:6807\:9898\"", Typeset`specs$$ = {{{
       Hold[$CellContext`pv$$], 0, 
       Row[{"Point of View", 
         Spacer[10]}]}, {0 -> "3D", 1 -> "Y-Z Plane", 2 -> "X-Y Plane"}}, {{
       Hold[$CellContext`L$$], 0.75, 
       Row[{"Length of the Shaft [m]", 
         Spacer[20]}]}, 0.1, 1}, {{
       Hold[$CellContext`R$$], 0.1, 
       Row[{"Radius of the Shaft [m]", 
         Spacer[22]}]}, 0.05, 0.1}, {{
       Hold[$CellContext`G$$], 4, 
       Row[{"Shear Modulus of the Shaft [MPa]", 
         Spacer[10]}]}, 4, 10}, {{
       Hold[$CellContext`T$$], 0, 
       Row[{"Magnitude of Torque [kN\[CenterDot]m]", 
         Spacer[38]}]}, -1, 1}, {
      Hold[
       Grid[{{
          Row[{
            Column[{
              Manipulate`Place[1], 
              Button[
              "Reset view", $CellContext`reset$$ = True, 
               ImageSize -> {90, 30}]}], 
            Spacer[30], 
            Column[{
              Manipulate`Place[2], 
              Manipulate`Place[3]}], 
            Spacer[30], 
            Column[{
              Manipulate`Place[4], 
              Manipulate`Place[5]}]}]}}, Alignment -> Left, 
        Spacings -> {Automatic, 1.5}]], Manipulate`Dump`ThisIsNotAControl}, {{
       Hold[$CellContext`reset$$], False}, 0}}, Typeset`size$$ = {
    800., {430.5, 436.5}}, Typeset`update$$ = 0, Typeset`initDone$$, 
    Typeset`skipInitDone$$ = True, $CellContext`pv$245776$$ = 
    False, $CellContext`L$245777$$ = 0, $CellContext`R$245778$$ = 
    0, $CellContext`G$245779$$ = 0, $CellContext`T$245780$$ = 0}, 
    DynamicBox[Manipulate`ManipulateBoxes[
     2, StandardForm, 
      "Variables" :> {$CellContext`G$$ = 4, $CellContext`L$$ = 
        0.75, $CellContext`pv$$ = 0, $CellContext`R$$ = 
        0.1, $CellContext`reset$$ = False, $CellContext`T$$ = 0}, 
      "ControllerVariables" :> {
        Hold[$CellContext`pv$$, $CellContext`pv$245776$$, False], 
        Hold[$CellContext`L$$, $CellContext`L$245777$$, 0], 
        Hold[$CellContext`R$$, $CellContext`R$245778$$, 0], 
        Hold[$CellContext`G$$, $CellContext`G$245779$$, 0], 
        Hold[$CellContext`T$$, $CellContext`T$245780$$, 0]}, 
      "OtherVariables" :> {
       Typeset`show$$, Typeset`bookmarkList$$, Typeset`bookmarkMode$$, 
        Typeset`animator$$, Typeset`animvar$$, Typeset`name$$, 
        Typeset`specs$$, Typeset`size$$, Typeset`update$$, Typeset`initDone$$,
         Typeset`skipInitDone$$}, "Body" :> 
      Module[{$CellContext`L0$, $CellContext`R0$, $CellContext`size$, \
$CellContext`reset1$, $CellContext`J$, $CellContext`\[Phi]$, \
$CellContext`sign$, $CellContext`show$, $CellContext`pd$, $CellContext`nd$, \
$CellContext`settings$, $CellContext`label$, $CellContext`view$, \
$CellContext`dwf1$, $CellContext`dwf2$, $CellContext`dwf3$, \
$CellContext`dwf4$, $CellContext`dwf5$, $CellContext`dwf6$, \
$CellContext`dwf7$, $CellContext`dwf8$, $CellContext`dwf9$, \
$CellContext`dwf10$, $CellContext`dwf11$, $CellContext`dw1$, \
$CellContext`dw2$, $CellContext`dw3$, $CellContext`dw4$, $CellContext`dw5$, \
$CellContext`dw6$, $CellContext`dw7$, $CellContext`dw8$, $CellContext`dw9$, \
$CellContext`dw10$}, $CellContext`L0$ = 1; $CellContext`R0$ = 
         0.1; $CellContext`size$ = 1.2 $CellContext`L0$; $CellContext`reset1$ = 
         If[$CellContext`reset$$, $CellContext`reset$$ = False; False, 
           True]; $CellContext`J$ = (Pi $CellContext`R$$^4)/
          2; $CellContext`\[Phi]$ = (((-1000) $CellContext`T$$) \
$CellContext`L$$)/((
           1000000 $CellContext`G$$) $CellContext`J$); $CellContext`sign$ = 
         Sign[$CellContext`\[Phi]$]; $CellContext`show$ = 
         If[Abs[$CellContext`T$$] > 0, 1, 0]; $CellContext`pd$ = 
         If[$CellContext`sign$ <= 0, $CellContext`pd$ = 1, $CellContext`pd$ = 
           0]; $CellContext`nd$ = 
         If[$CellContext`sign$ > 0, $CellContext`nd$ = 1, $CellContext`nd$ = 
           0]; If[$CellContext`pv$$ == 
          0, $CellContext`view$ = {(1. 
             100) $CellContext`size$, (-100) $CellContext`size$, (0.75 
             100) $CellContext`size$}, 
          
          If[$CellContext`pv$$ == 
           1, $CellContext`view$ = {
            100 $CellContext`size$, 0, 0}, $CellContext`view$ = {
            0, 0, 100 $CellContext`size$}]]; $CellContext`settings$ = {
          Boxed -> False, ViewPoint -> $CellContext`view$, SphericalRegion -> 
           True, ImageSize -> 800, 
           PlotRange -> {{(-0.1) $CellContext`size$, 
              1 $CellContext`size$}, {(-0.18) $CellContext`size$, 
              0.18 $CellContext`size$}, {(-0.18) $CellContext`size$, 
              0.18 $CellContext`size$}}}; $CellContext`dwf1$ = {
           Opacity[1], 
           Dashing[{}], 
           Thickness[0.002], 
           Arrowheads[0.02], 
           Arrow[{{0, 0, 0}, {1.2 $CellContext`L$$, 0, 0}}], 
           Arrow[{{0, 0, 0}, {0, 2 $CellContext`R0$, 0}}], 
           Arrow[{{0, 0, 0}, {0, 0, 2 $CellContext`R0$}}], FontSize -> 20, 
           Text[
           "\!\(\*\nStyleBox[\"x\",\nFontFamily->\"Times New Roman\",\n\
FontWeight->\"Bold\",\nFontSlant->\"Italic\"]\)", {
            1.25 $CellContext`L$$, 0, 0}], 
           Text[
           "\!\(\*\nStyleBox[\"y\",\nFontFamily->\"Times New Roman\",\n\
FontWeight->\"Bold\",\nFontSlant->\"Italic\"]\)", {
            0, 2.2 $CellContext`R0$, 0}], 
           Text[
           "\!\(\*\nStyleBox[\"z\",\nFontFamily->\"Times New Roman\",\n\
FontWeight->\"Bold\",\nFontSlant->\"Italic\"]\)", {
            0, 0, 2.2 $CellContext`R0$}]}; $CellContext`dwf2$ = {
           Opacity[0.8], Gray, 
           
           Cuboid[{(-0.1) $CellContext`R0$, (-1.25) $CellContext`R0$, (-1.25) \
$CellContext`R0$}, {
            0, 1.25 $CellContext`R0$, 
             1.25 $CellContext`R0$}]}; $CellContext`dwf3$ = {
           Opacity[0.4], LightBlue, 
           
           Cylinder[{{0, 0, 
             0}, {$CellContext`L$$, 0, 
              0}}, $CellContext`R$$]}; $CellContext`dwf4$ = {
           Opacity[$CellContext`show$], Black, 
           Thickness[0.005], 
           
           Line[{{0, 0, $CellContext`R$$}, {$CellContext`L$$, 
              0, $CellContext`R$$}}], 
           
           Line[{{$CellContext`L$$, 0, 0}, {$CellContext`L$$, 
              0, $CellContext`R$$}}], 
           Opacity[1], Red, 
           
           Line[{{$CellContext`L$$, 0, 
              0}, {$CellContext`L$$, $CellContext`R$$ 
              Sin[$CellContext`\[Phi]$], $CellContext`R$$ 
              Cos[$CellContext`\[Phi]$]}}]}; $CellContext`dwf5$ = {
           Opacity[0], 
           If[Abs[$CellContext`T$$] > 0, 
            
            Cylinder[{{1.1 $CellContext`L$$, 0, 0}, {
              1.1 $CellContext`L$$ + 1.*^-6, 0, 0}}, $CellContext`R$$/
             2]]}; $CellContext`dwf6$ = {
           Opacity[$CellContext`show$], Red, 
           If[Abs[$CellContext`T$$] > 0, 
            
            Cone[{{1.1 $CellContext`L$$, ((-$CellContext`R$$)/2) 
               Sin[Sign[$CellContext`\[Phi]$] (Pi/10)], $CellContext`R$$/2}, {
              1.1 $CellContext`L$$, ($CellContext`R$$/2) 
               Sin[Sign[$CellContext`\[Phi]$] (Pi/10)], $CellContext`R$$/2}}, 
             0.0075]], Black, FontSize -> 16, 
           Text[
           "\!\(\*\nStyleBox[\"T\",\nFontFamily->\"Times New Roman\",\n\
FontWeight->\"Bold\",\nFontSlant->\"Italic\",\nFontColor->RGBColor[0., 0., \
0.]]\)", {1.1 $CellContext`L$$ + 0.02, $CellContext`R$$/4, $CellContext`R$$/
             2}]}; $CellContext`dwf7$ = {Blue, 
           Thickness[0.002], 
           
           Line[{{$CellContext`L$$, 0, 0}, {$CellContext`L$$, 
              2 $CellContext`R$$, 0}}], 
           Arrowheads[0.02], 
           
           Arrow[{{$CellContext`L$$, 2 $CellContext`R$$, 0}, {
             0, 2 $CellContext`R$$, 0}}], 
           
           Arrow[{{0, 2 $CellContext`R$$, 0}, {$CellContext`L$$, 
              2 $CellContext`R$$, 0}}], FontSize -> 16, 
           Text[
           "\!\(\*\nStyleBox[\"L\",\nFontFamily->\"Times New Roman\",\n\
FontWeight->\"Bold\",\nFontSlant->\"Italic\",\nFontColor->RGBColor[0., 0., \
0.]]\)", {$CellContext`L$$/2, 2.1 $CellContext`R$$, $CellContext`R$$/5}], 
           Arrowheads[0.02], 
           
           Arrow[{{$CellContext`L$$, 0, 
              0}, {$CellContext`L$$, $CellContext`R$$ 
              Cos[(-Pi)/3], $CellContext`R$$ Sin[(-Pi)/3]}}], FontSize -> 16, 
           Text[
           "\!\(\*\nStyleBox[\"R\",\nFontFamily->\"Times New Roman\",\n\
FontWeight->\"Bold\",\nFontSlant->\"Italic\"]\)", {
            1.02 $CellContext`L$$, ($CellContext`R$$/2) 
              Cos[(-Pi)/3] + $CellContext`R$$/10, ($CellContext`R$$/2) 
              Sin[(-Pi)/3] + $CellContext`R$$/10}]}; $CellContext`dwf8$ = {
           Opacity[$CellContext`show$], Black, 
           Thickness[0.002], 
           
           Line[{{$CellContext`L$$, 0, 0}, {$CellContext`L$$, 0, 
              2 $CellContext`R$$}}], 
           
           Line[{{$CellContext`L$$, 0, 
              0}, {$CellContext`L$$, (2 $CellContext`R$$) 
              Sin[$CellContext`\[Phi]$], (2 $CellContext`R$$) 
              Cos[$CellContext`\[Phi]$]}}]}; $CellContext`dwf9$ = {
           Opacity[$CellContext`show$], FontSize -> 20, 
           Text[
           "\!\(\*\nStyleBox[FormBox[\"\[Phi]\",\n  TraditionalForm],\n\
FontFamily->\"Times New Roman\",\nFontWeight->\"Bold\",\n\
FontSlant->\"Italic\",\nFontColor->RGBColor[0., 0., 0.]]\)", \
{$CellContext`L$$, (2.3 $CellContext`R$$) 
             Sin[$CellContext`\[Phi]$/2], (2.3 $CellContext`R$$) 
             Cos[$CellContext`\[Phi]$/2]}]}; $CellContext`dwf10$ = {
           Opacity[$CellContext`show$], FontSize -> 16, 
           If[$CellContext`T$$ <= 0, 
            Text[
            "\!\(\*\nStyleBox[\"Undeformed\",\nFontFamily->\"Times New \
Roman\",\nFontWeight->\"Bold\",\nFontColor->RGBColor[0., 0., 0.]]\)\!\(\*\n\
StyleBox[\" \",\nFontFamily->\"Times New Roman\",\nFontWeight->\"Bold\",\n\
FontColor->RGBColor[0., 0., 0.]]\)\!\(\*\nStyleBox[\"Plane\",\n\
FontFamily->\"Times New Roman\",\nFontWeight->\"Bold\",\n\
FontColor->RGBColor[0., 0., 0.]]\)", {$CellContext`L$$/
              1.5, (1.5 $CellContext`R$$) 
              Sin[Pi + Pi/3], (1.5 $CellContext`R$$) Cos[Pi + Pi/3] + 
              2.5 $CellContext`R$$}], 
            Text[
            "\!\(\*\nStyleBox[\"Undeformed\",\nFontFamily->\"Times New \
Roman\",\nFontWeight->\"Bold\",\nFontColor->RGBColor[0., 0., 0.]]\)\!\(\*\n\
StyleBox[\" \",\nFontFamily->\"Times New Roman\",\nFontWeight->\"Bold\",\n\
FontColor->RGBColor[0., 0., 0.]]\)\!\(\*\nStyleBox[\"Plane\",\n\
FontFamily->\"Times New Roman\",\nFontWeight->\"Bold\",\n\
FontColor->RGBColor[0., 0., 0.]]\)", {$CellContext`L$$/
              1.5, (1.5 $CellContext`R$$) 
              Sin[-Pi - Pi/3], (1.5 $CellContext`R$$) Cos[-Pi - Pi/3] + 
              2.5 $CellContext`R$$}]]}; $CellContext`dwf11$ = {
           Opacity[$CellContext`show$], 
           If[$CellContext`T$$ >= 0, 
            
            Line[{{$CellContext`L$$/1.5, $CellContext`R$$ 
               Sin[$CellContext`\[Phi]$/1.5], $CellContext`R$$ 
               Cos[$CellContext`\[Phi]$/1.5]}, {$CellContext`L$$/
               1.5, (2 $CellContext`R$$) 
                Sin[$CellContext`\[Phi]$/1.5] - $CellContext`R$$, (
                2 $CellContext`R$$) Cos[$CellContext`\[Phi]$/1.5]}}], 
            
            Line[{{$CellContext`L$$/1.5, $CellContext`R$$ 
               Sin[$CellContext`\[Phi]$/1.5], $CellContext`R$$ 
               Cos[$CellContext`\[Phi]$/1.5]}, {$CellContext`L$$/
               1.5, (2 $CellContext`R$$) 
                Sin[$CellContext`\[Phi]$/1.5] + $CellContext`R$$, (
                2 $CellContext`R$$) Cos[$CellContext`\[Phi]$/1.5]}}]], 
           FontSize -> 16, 
           If[$CellContext`T$$ >= 0, 
            Text[
            "\!\(\*\nStyleBox[\"Deformed\",\nFontFamily->\"Times New Roman\",\
\nFontWeight->\"Bold\",\nFontColor->RGBColor[0., 0., 0.]]\)\!\(\*\n\
StyleBox[\" \",\nFontFamily->\"Times New Roman\",\nFontWeight->\"Bold\",\n\
FontColor->RGBColor[0., 0., 0.]]\)\!\(\*\nStyleBox[\"Plane\",\n\
FontFamily->\"Times New Roman\",\nFontWeight->\"Bold\",\n\
FontColor->RGBColor[0., 0., 0.]]\)", {$CellContext`L$$/
              1.5, (2 $CellContext`R$$) 
               Sin[$CellContext`\[Phi]$/1.5] - $CellContext`R$$, (
                2 $CellContext`R$$) Cos[$CellContext`\[Phi]$/1.5] + 
              0.1 $CellContext`R$$}], 
            Text[
            "\!\(\*\nStyleBox[\"Deformed\",\nFontFamily->\"Times New Roman\",\
\nFontWeight->\"Bold\",\nFontColor->RGBColor[0., 0., 0.]]\)\!\(\*\n\
StyleBox[\" \",\nFontFamily->\"Times New Roman\",\nFontWeight->\"Bold\",\n\
FontColor->RGBColor[0., 0., 0.]]\)\!\(\*\nStyleBox[\"Plane\",\n\
FontFamily->\"Times New Roman\",\nFontWeight->\"Bold\",\n\
FontColor->RGBColor[0., 0., 0.]]\)", {$CellContext`L$$/
              1.5, (2 $CellContext`R$$) 
               Sin[$CellContext`\[Phi]$/1.5] + $CellContext`R$$, (
                2 $CellContext`R$$) Cos[$CellContext`\[Phi]$/1.5] + 
              0.1 $CellContext`R$$}]]}; $CellContext`dw1$ = 
         Graphics3D[{$CellContext`dwf1$, $CellContext`dwf2$, \
$CellContext`dwf3$, $CellContext`dwf4$, $CellContext`dwf6$, \
$CellContext`dwf7$, $CellContext`dwf8$, $CellContext`dwf9$, \
$CellContext`dwf10$, $CellContext`dwf11$, 
            EdgeForm[
             Directive[Thick, Red, 
              Opacity[1]]], $CellContext`dwf5$}, $CellContext`settings$, 
           PreserveImageOptions -> $CellContext`reset1$]; $CellContext`dw2$ = {
           
           ParametricPlot3D[{$CellContext`L$$/2, $CellContext`R$$ 
             Sin[$CellContext`\[Phi]$], $CellContext`R$$ 
             Cos[$CellContext`\[Phi]$]}, {$CellContext`\[Phi]$, 0, 2 Pi}, 
            Boxed -> False, ViewPoint -> $CellContext`view$, PlotStyle -> 
            Red]}; $CellContext`dw3$ = {
           
           ParametricPlot3D[{$CellContext`x, $CellContext`R$$ 
             Sin[$CellContext`\[Phi]$ ($CellContext`x/$CellContext`L$$)], \
$CellContext`R$$ 
             Cos[$CellContext`\[Phi]$ ($CellContext`x/$CellContext`L$$)]}, \
{$CellContext`x, 0, $CellContext`L$$}, Boxed -> False, 
            ViewPoint -> $CellContext`view$, PlotStyle -> 
            Red]}; $CellContext`dw4$ = {
           If[Abs[$CellContext`T$$] > 0, 
            
            ParametricPlot3D[{$CellContext`x, 
              0, $CellContext`z}, {$CellContext`x, 
              0, $CellContext`L$$}, {$CellContext`z, 0, $CellContext`R$$}, 
             Boxed -> False, ViewPoint -> $CellContext`view$, 
             PlotStyle -> {Green, 
               Opacity[1]}]]}; $CellContext`dw5$ = {
           If[Abs[$CellContext`T$$] > 0, 
            
            ParametricPlot3D[{$CellContext`x, $CellContext`z 
              Sin[($CellContext`x/$CellContext`L$$) $CellContext`\[Phi]$], \
$CellContext`z 
              Cos[($CellContext`x/$CellContext`L$$) $CellContext`\[Phi]$]}, \
{$CellContext`x, 0, $CellContext`L$$}, {$CellContext`z, 0, $CellContext`R$$}, 
             Boxed -> False, ViewPoint -> $CellContext`view$, 
             PlotStyle -> {Blue, 
               Opacity[1]}]]}; $CellContext`dw6$ = {
           If[Abs[$CellContext`T$$] > 0, 
            
            ParametricPlot3D[{$CellContext`L$$, (2 $CellContext`R$$) 
              Sin[$CellContext`x], (2 $CellContext`R$$) 
              Cos[$CellContext`x]}, {$CellContext`x, 0, $CellContext`\[Phi]$},
              Boxed -> False, ViewPoint -> $CellContext`view$, 
             PlotStyle -> {Black, 
               Opacity[$CellContext`show$], 
               Thickness[0.0025]}]]}; $CellContext`dw7$ = {
           If[Abs[$CellContext`T$$] > 0, 
            
            ParametricPlot3D[{$CellContext`L$$/
              1.5, (1.5 $CellContext`R$$) Sin[$CellContext`x] + 
              0, (1.5 $CellContext`R$$) Cos[$CellContext`x] + 
              2.4 $CellContext`R$$}, {$CellContext`x, (-Pi)/2 - Pi/2, (-Pi)/2 - 
              Pi/2 - Pi/3}, Boxed -> False, ViewPoint -> $CellContext`view$, 
             PlotStyle -> {Black, 
               Opacity[$CellContext`pd$], 
               Thickness[0.0025]}]]}; $CellContext`dw8$ = {
           If[Abs[$CellContext`T$$] > 0, 
            
            ParametricPlot3D[{$CellContext`L$$/
              1.5, (1.5 $CellContext`R$$) Sin[$CellContext`x] + 
              0, (1.5 $CellContext`R$$) Cos[$CellContext`x] + 
              2.4 $CellContext`R$$}, {$CellContext`x, Pi/2 + Pi/2, Pi/2 + 
              Pi/2 + Pi/3}, Boxed -> False, ViewPoint -> $CellContext`view$, 
             PlotStyle -> {Black, 
               Opacity[$CellContext`nd$], 
               Thickness[0.0025]}]]}; Column[{
           Text[
            
            Grid[{{"Input Parameters and Calculated Values", SpanFromLeft}, {
              "L[m]", "R[m]", "G[MPa]", "T[kN\[CenterDot]m]", 
               "\[Phi][\[Degree]]"}, 
              
              Round[{$CellContext`L$$, $CellContext`R$$, $CellContext`G$$, \
$CellContext`T$$, (-$CellContext`\[Phi]$) (180/Pi)}, 0.01]}, ItemSize -> 5, 
             Frame -> All, Background -> {None, {
                Lighter[Gray, 0.95]}}]], 
           If[Abs[$CellContext`T$$] > 0, 
            
            Show[$CellContext`dw1$, $CellContext`dw2$, $CellContext`dw3$, \
$CellContext`dw4$, $CellContext`dw5$, $CellContext`dw6$, $CellContext`dw7$, \
$CellContext`dw8$], 
            Show[$CellContext`dw1$, $CellContext`dw2$, $CellContext`dw3$]]}]],
       "Specifications" :> {{{$CellContext`pv$$, 0, 
          Row[{"Point of View", 
            Spacer[10]}]}, {0 -> "3D", 1 -> "Y-Z Plane", 2 -> "X-Y Plane"}, 
         ControlType -> RadioButton, ControlPlacement -> 
         1}, {{$CellContext`L$$, 0.75, 
          Row[{"Length of the Shaft [m]", 
            Spacer[20]}]}, 0.1, 1, ImageSize -> Small, Appearance -> 
         "Labeled", ControlPlacement -> 2}, {{$CellContext`R$$, 0.1, 
          Row[{"Radius of the Shaft [m]", 
            Spacer[22]}]}, 0.05, 0.1, ImageSize -> Small, Appearance -> 
         "Labeled", ControlPlacement -> 3}, {{$CellContext`G$$, 4, 
          Row[{"Shear Modulus of the Shaft [MPa]", 
            Spacer[10]}]}, 4, 10, ImageSize -> Small, Appearance -> "Labeled",
          ControlPlacement -> 4}, {{$CellContext`T$$, 0, 
          Row[{"Magnitude of Torque [kN\[CenterDot]m]", 
            Spacer[38]}]}, -1, 1, ImageSize -> Small, Appearance -> "Labeled",
          ControlPlacement -> 5}, 
        Grid[{{
           Row[{
             Column[{
               Manipulate`Place[1], 
               Button[
               "Reset view", $CellContext`reset$$ = True, 
                ImageSize -> {90, 30}]}], 
             Spacer[30], 
             Column[{
               Manipulate`Place[2], 
               Manipulate`Place[3]}], 
             Spacer[30], 
             Column[{
               Manipulate`Place[4], 
               Manipulate`Place[5]}]}]}}, Alignment -> Left, 
         Spacings -> {Automatic, 1.5}], {{$CellContext`reset$$, False}, 0, 
         ControlType -> None}}, "Options" :> {ControlPlacement -> Top}, 
      "DefaultOptions" :> {}],
     ImageSizeCache->{1009., {490., 496.}},
     SingleEvaluation->True],
    Deinitialization:>None,
    DynamicModuleValues:>{},
    SynchronousInitialization->True,
    UndoTrackedVariables:>{Typeset`show$$, Typeset`bookmarkMode$$},
    UnsavedVariables:>{Typeset`initDone$$},
    UntrackedVariables:>{Typeset`size$$}], "Manipulate",
   Deployed->True,
   StripOnInput->False],
  Manipulate`InterpretManipulate[1]]], "Output",
 TextAlignment->Center,
 ExpressionUUID -> "a94ae9fe-53c2-4805-98c7-02a1632c72ac"]
},
WindowSize->{1920, 997},
Visible->True,
ScrollingOptions->{"VerticalScrollRange"->Fit},
ShowCellBracket->Automatic,
CellContext->Notebook,
TrackCellChangeTimes->False,
FrontEndVersion->"11.0 for Microsoft Windows (64-bit) (July 28, 2016)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[1464, 33, 321, 9, 117, "Text"],
Cell[1788, 44, 678, 21, 49, "Text"],
Cell[2469, 67, 610, 23, 42, "Text"],
Cell[3082, 92, 304, 8, 49, "Text"],
Cell[3389, 102, 296, 11, 42, "Text"],
Cell[3688, 115, 197, 7, 30, "Text"],
Cell[3888, 124, 20019, 400, 1003, "Output"]
}
]
*)

(* End of internal cache information *)

(* NotebookSignature 3u0tpUhRAC7AGBwKD2fWL1w6 *)
